@@ -8,9 +8,6 @@ require(RUnit); require(xlsx)
 
 dirUT <- paste(.Library, "/xlsx/tests", sep="")
 
-source(paste(dirUT, "/test.workbook.R", sep=""))
-test.lowlevel()
-
 source(paste(dirUT, "/test.workbook.R", sep=""))
 test.workbook()
 
@@ -20,6 +17,8 @@ test.formats()
 source(paste(dirUT, "/test.import.R", sep=""))
 test.import()
 
+source(paste(dirUT, "/test.export.R", sep=""))
+test.export()
 
 
 
